@@ -49,26 +49,30 @@ static FILE *g_fin = NULL;
 static inline uint32_t bswap32(const uint32_t u32)
 {
 #ifndef WORDS_BIGENDIAN
-#ifdef _MSC_VER
-	return _byteswap_ulong(u32);
-#else
+#if defined (__GNUC__) && ((__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 3)))
     return __builtin_bswap32(u32);
+#elif defined (_MSC_VER)
+    return _byteswap_ulong(u32);
+#else
+    return (u32 << 24) | ((u32 << 8) & 0xFF0000) | ((u32 >> 8) & 0xFF00) | (u32 >> 24);
 #endif
 #else
-	return u32;
+    return u32;
 #endif
 }
 
 static inline uint16_t bswap16(const uint16_t u16)
 {
 #ifndef WORDS_BIGENDIAN
-#ifdef _MSC_VER
-	return _byteswap_ushort(u16);
+#if defined (__GNUC__) && ((__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 8)))
+    return __builtin_bswap16(u16);
+#elif defined (_MSC_VER)
+    return _byteswap_ushort(u16);
 #else
-	return __builtin_bswap16(u16);
+    return (u16 << 8) | (u16 >> 8);
 #endif
 #else
-	return u16;
+    return u16;
 #endif
 }
 
@@ -466,7 +470,7 @@ static int ilstin(int size)
         {"Genre       ", "gnre", GENRE},
         {"Grouping    ", "\xa9" "grp"},
         {"Lyrics      ", "\xa9" "lyr"},
-        {"Tille       ", "\xa9" "nam"},
+        {"Title       ", "\xa9" "nam"},
         {"Rating      ", "rtng"},
         {"BPM         ", "tmpo"},
         {"Encoder     ", "\xa9" "too"},
@@ -793,7 +797,8 @@ static int moovin(int sizemax)
 {
     long apos = ftell(g_fin);
     uint32_t atomsize;
-    int err;
+    creator_t *old_atom = g_atom;
+    int err, ret = sizemax;
 
     static creator_t mvhd[] = {
         {ATOM_NAME, "mvhd"},
@@ -837,8 +842,11 @@ static int moovin(int sizemax)
 
     g_atom = mvhd;
     atomsize = sizemax + apos - ftell(g_fin);
-    if (parse(&atomsize) < 0)
+    if (parse(&atomsize) < 0) {
+        g_atom = old_atom;
         return ERR_FAIL;
+    }
+
     fseek(g_fin, apos, SEEK_SET);
 
     while (1)
@@ -852,13 +860,16 @@ static int moovin(int sizemax)
         err = parse(&atomsize);
         //fprintf(stderr, "SIZE: %x/%x\n", atomsize, sizemax);
         if (err >= 0)
-            return sizemax;
-        if (err != ERR_UNSUPPORTED)
-            return err;
+            break;
+        if (err != ERR_UNSUPPORTED) {
+            ret = err;
+            break;
+        }
         //fprintf(stderr, "UNSUPP\n");
     }
 
-    return sizemax;
+    g_atom = old_atom;
+    return ret;
 }
 
 
